@@ -39,16 +39,21 @@ sub awx_configure {
 sub wxwidgets_configure_extra_flags {
     my( $self ) = @_;
     my $extra_flags = $self->notes( 'extraflags' );
-    return $extra_flags if $extra_flags;
-    
-    print qq(Standard Mac Flags in use\n);
     
+    if($extra_flags) {
+    	if( $self->notes( 'graphicscontext' ) ) {
+			$extra_flags .= ' --enable-graphics_ctx';
+    	}
+        return $extra_flags;
+    }
+        
     my $darwinver = 0;
     if(`uname -r` =~ /^(\d+)\./) {
         $darwinver = $1;
     }
     
     # on Snow Leopard, force wxWidgets 2.8.x builds to be 32-bit;
+    
     if(    $self->notes( 'build_data' )->{data}{version} =~ /^2.8/
         && $darwinver >= 10
         && `sysctl hw.cpu64bit_capable` =~ /^hw.cpu64bit_capable: 1/ ) {
@@ -57,11 +62,20 @@ sub wxwidgets_configure_extra_flags {
                                      qw(CFLAGS CXXFLAGS LDFLAGS
                                         OBJCFLAGS OBJCXXFLAGS);
     }
-    # build fix for 2.9.x on darwin 10 +
-    if( $darwinver >= 10
-        && $self->notes( 'build_data' )->{data}{version} =~ /^2.9/ ) {
-        $extra_flags .= ' --with-macosx-version-min=10.5';
+    
+    # on Snow Leopard and Lion force use of 10.6 SDK for all current builds
+    if( $darwinver >= 10 ) {
+	    $extra_flags .= ' --with-macosx-version-min=10.5 --with-macosx-sdk=/Developer/SDKs/MacOSX10.6.sdk';
     }
+    
+    ## build fix for 2.9.x on darwin 10 +
+    #if( $darwinver >= 10
+    #    && $self->notes( 'build_data' )->{data}{version} =~ /^2.9/ ) {
+    #    $extra_flags .= ' --with-macosx-version-min=10.5';
+    #}
+    
+    # by default always add graphics context
+	$extra_flags .= ' --enable-graphics_ctx';
 
     return $extra_flags;
 }
