@@ -5,9 +5,12 @@ use base qw(My::Build::Win32);
 use My::Build::Utility qw(awx_arch_file awx_install_arch_file
                           awx_install_arch_dir awx_arch_dir);
 use Config;
+use File::Basename qw();
+use File::Glob qw(bsd_glob);
 
 sub _find_make {
-    my( @try ) = qw(mingw32-make make);
+    my( @try ) = qw(mingw32-make gmake make);
+    push @try, $Config{gmake} if $Config{gmake};
 
     foreach my $name ( @try ) {
         foreach my $dir ( File::Spec->path ) {
@@ -23,19 +26,21 @@ sub awx_configure {
     my $self = shift;
     my %config = $self->SUPER::awx_configure;
 
-    $config{c_flags} .= " -fvtable-thunks ";
+	my $mxarchflags = ( $Config{ptrsize} == 8 ) ? '-m64' : '-m32';
 
     if( $self->awx_debug ) {
-        $config{c_flags} .= ' -g ';
+        $config{c_flags} .= qq( -g $mxarchflags );
+        $config{link_flags} .= qq( $mxarchflags );
     } else {
-        $config{link_flags} .= ' -s ';
+        $config{c_flags} .= qq( $mxarchflags );
+        $config{link_flags} .= qq( -s $mxarchflags );
     }
 
     my $cccflags = $self->wx_config( 'cxxflags' );
     my $libs = $self->wx_config( 'libs' );
     my $incdir = $self->awx_wx_config_data->{wxinc};
     my $cincdir = $self->awx_wx_config_data->{wxcontrinc};
-    my $iincdir = awx_install_arch_dir( 'rEpLaCe/include' );
+    my $iincdir = awx_install_arch_dir( $self, 'rEpLaCe/include' );
 
     foreach ( split /\s+/, $cccflags ) {
         m(^-DSTRICT) && next;
@@ -49,7 +54,7 @@ sub awx_configure {
             }
             if( $_ =~ /-I\Q$self->{awx_setup_dir}\E/ ) {
                 $config{include_path} .=
-                  '-I' . awx_install_arch_file( 'rEpLaCe/lib' ) . ' ';
+                  '-I' . awx_install_arch_file( $self, 'rEpLaCe/lib' ) . ' ';
             } else {
                 $config{include_path} .= "$_ ";
             }
@@ -88,20 +93,49 @@ sub awx_compiler_kind { 'gcc' }
 
 sub files_to_install {
     my $self = shift;
-    my $dll = 'mingwm10.dll';
-    my $dll_from = $self->awx_path_search( $dll );
+    my( @try ) = qw(libgcc_*.dll mingwm10.dll);
+    my( $dll, $dll_from );
+    
+    # TODO: we need to determine this by testing one of
+    # the build DLL's
+    #
+    # A mingw build may link as static or dynamic to libgcc
+    # and libstdc++
 
-    return ( $self->SUPER::files_to_install(),
+    foreach my $d ( @try ) {
+        $dll_from = $self->awx_path_search( $d );
+        if( defined $dll_from ) {
+            $dll = File::Basename::basename( $dll_from );
+            last;
+        }
+    }
+    
+    if(!defined($dll)) {
+        # check for special case ActivePerl mingw PPM
+        my $ppmmingw = qq($Config{sitearch}/auto/MinGW/bin/mingwm10.dll);
+        if( -f $ppmmingw ) {
+            $dll_from = $ppmmingw;
+            $dll = File::Basename::basename( $dll_from );
+        }
+    }
+    
+    if( defined( $dll_from ) && defined( $dll ) ) {
+        return ( $self->SUPER::files_to_install(),
              ( $dll_from => awx_arch_file( "rEpLaCe/lib/$dll" ) ) );
+    } else {
+        die 'Cannot find libc (mingwm10.dll/ libgcc_*.dll) for install';
+    }
+
 }
 
 sub awx_strip_dlls {
     my( $self ) = @_;
-    my( $dir ) = grep !/Config/, glob( awx_arch_dir( '*' ) );
+    my( $dir ) = grep !/Config/, bsd_glob( awx_arch_dir( '*' ) );
 
     $self->_system( "attrib -r $dir\\lib\\*.dll" );
     $self->_system( "strip $dir\\lib\\*.dll" );
     $self->_system( "attrib +r $dir\\lib\\*.dll" );
 }
 
+
 1;
